import * as api from './api'
import { dict, UserPageQuery, compute, CreateCrudOptionsProps, CreateCrudOptionsRet } from '@fast-crud/fast-crud'
import { inject } from 'vue'
import { BaseColumn } from '/@/views/adManage/utils/commonTabColumn.js'
import { parseQueryParams } from '/@/views/adManage/utils/tools.js'
import XEUtils from 'xe-utils'

export const createCrudOptions = function ({ crudExpose, context }: CreateCrudOptionsProps): CreateCrudOptionsRet {
	const pageRequest = async (query: UserPageQuery) => {
		const params = parseQueryParams(context.value)
		XEUtils.assign(query, params)
		return await api.GetList(query)
	}

	//权限判定
	const hasPermissions = inject('$hasPermissions')

	return {
		crudOptions: {
			table: {
				height: 800,
				rowKey: (row: any) => row.keywordId + row.searchTerm,
			},
			container: {
				fixedHeight: false,
			},
			actionbar: {
				show: false,
			},
			search: {
				show: false,
			},
			toolbar: {
				buttons: {
					search: {
						show: true,
					},
					compact: {
						show: false,
					},
				},
			},
			request: {
				pageRequest,
			},
			rowHandle: {
				show: false,
			},
			columns: {
				searchTerm: {
					title: '搜索词',
				},
				matchType: {
					title: '定向',
				},
				campaignName: {
					title: '广告活动',
				},
				adGroupName: {
					title: '广告组',
				},
				...BaseColumn,
			},
		},
	}
}
